==> owncloud-8.2.2p3.tgz: owncloud/apps/files/l10n/lb.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Et ass en onbekannte Fehler opgetrueden",
    "There is no error, the file uploaded with success" : "Keen Feeler, Datei ass komplett ropgelueden ginn",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
    "The uploaded file was only partially uploaded" : "Déi ropgelueden Datei ass nëmmen hallef ropgelueden ginn",
    "No file was uploaded" : "Et ass kee Fichier ropgeluede ginn",
    "Missing a temporary folder" : "Et feelt en temporären Dossier",
    "Failed to write to disk" : "Konnt net op den Disk schreiwen",
    "Files" : "Dateien",
    "Favorites" : "Favoriten",
    "Home" : "Doheem",
    "Close" : "Zoumaachen",
    "Upload cancelled." : "Upload ofgebrach.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "File Upload am gaang. Wann's de des Säit verléiss gëtt den Upload ofgebrach.",
    "Download" : "Download",
    "Rename" : "Ëmbenennen",
    "Delete" : "Läschen",
    "Details" : "Detailer",
    "Select" : "Auswielen",
    "Error" : "Fehler",
    "Name" : "Numm",
    "Size" : "Gréisst",
    "Modified" : "Geännert",
    "New" : "Nei",
    "Upload" : "Eroplueden",
    "Text file" : "Text Fichier",
    "Folder" : "Dossier",
    "New folder" : "Neien Dossier",
    "File handling" : "Fichier handling",
    "Maximum upload size" : "Maximum Upload Gréisst ",
    "max. possible: " : "max. méiglech:",
    "Save" : "Späicheren",
    "Settings" : "Astellungen",
    "Cancel upload" : "Upload ofbriechen",
    "No entries found in this folder" : "Keng Elementer an dësem Dossier fonnt",
    "Select all" : "All auswielen",
    "Upload too large" : "Upload ze grouss",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Déi Dateien déi Dir probéiert erop ze lueden sinn méi grouss wei déi Maximal Gréisst déi op dësem Server erlaabt ass.",
    "Files are being scanned, please wait." : "Fichieren gi gescannt, war weg.",
    "Upload cancelled." : "Upload ofgebrach."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/lb.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Et ass en onbekannte Fehler opgetrueden",
    "There is no error, the file uploaded with success" : "Keen Feeler, Datei ass komplett ropgelueden ginn",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
    "The uploaded file was only partially uploaded" : "Déi ropgelueden Datei ass nëmmen hallef ropgelueden ginn",
    "No file was uploaded" : "Et ass kee Fichier ropgeluede ginn",
    "Missing a temporary folder" : "Et feelt en temporären Dossier",
    "Failed to write to disk" : "Konnt net op den Disk schreiwen",
    "Files" : "Dateien",
    "Favorites" : "Favoriten",
    "Home" : "Doheem",
    "Close" : "Zoumaachen",
    "Upload cancelled." : "Upload ofgebrach.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "File Upload am gaang. Wann's de des Säit verléiss gëtt den Upload ofgebrach.",
    "Download" : "Download",
    "Rename" : "Ëmbenennen",
    "Delete" : "Läschen",
    "Unshare" : "Net méi deelen",
    "Details" : "Detailer",
    "Select" : "Auswielen",
    "Name" : "Numm",
    "Size" : "Gréisst",
    "Modified" : "Geännert",
    "New" : "Nei",
    "Folder" : "Dossier",
    "New folder" : "Neien Dossier",
    "Upload" : "Eroplueden",
    "File handling" : "Fichier handling",
    "Maximum upload size" : "Maximum Upload Gréisst ",
    "max. possible: " : "max. méiglech:",
    "Save" : "Späicheren",
    "Settings" : "Astellungen",
    "Cancel upload" : "Upload ofbriechen",
    "No entries found in this folder" : "Keng Elementer an dësem Dossier fonnt",
    "Select all" : "All auswielen",
    "Upload too large" : "Upload ze grouss",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Déi Dateien déi Dir probéiert erop ze lueden sinn méi grouss wei déi Maximal Gréisst déi op dësem Server erlaabt ass.",
    "Text file" : "Text Fichier",
    "Upload cancelled." : "Upload ofgebrach."
},
"nplurals=2; plural=(n != 1);");
